AdversarialLoss
===============

.. currentmodule:: pykeen.losses

.. autoclass:: AdversarialLoss
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AdversarialLoss.forward
      ~AdversarialLoss.negative_loss_term_unreduced
      ~AdversarialLoss.positive_loss_term
      ~AdversarialLoss.process_lcwa_scores
      ~AdversarialLoss.process_slcwa_scores

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: negative_loss_term_unreduced
   .. automethod:: positive_loss_term
   .. automethod:: process_lcwa_scores
   .. automethod:: process_slcwa_scores
